@@ -4,13 +4,14 @@ package CGI::Portal::Scripts::logoff;
 # Remove session
 
 use strict;
-use CGI::Portal::Scripts::logon;
-use CGI::Portal::Sessions;
+
+use CGI::Portal::Scripts;
 
 use vars qw(@ISA $VERSION);
-$VERSION = "0.10";
 
-@ISA = qw(CGI::Portal::Sessions);
+$VERSION = "0.12";
+
+@ISA = qw(CGI::Portal::Scripts);
 
 1;
 
@@ -23,9 +24,9 @@ sub launch {
 
             # Remove session
     $self->logoff;
-
-            # Redirect
-    bless $self, "CGI::Portal::Scripts::logon";
-    $self->launch;
+    $self->{'tmpl_vars'}{'result'} = "You are logged off.";
   }
+
+            # Assign tmpl
+  $self->assign_tmpl("Sessions.html");
 }
\ No newline at end of file
